/*
 * Pan - A Newsreader for X
 * Copyright (C) 1999, 2000  Pan Development Team <pan@rebelbase.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */

#ifndef __DIALOGS_H__
#define __DIALOGS_H__

#include <pan/base/group.h>

void dialog_about	        (GtkWidget * window);

void dialog_download_headers	(GtkWindow * parent, Group *);

void dialog_newuser	        (void);

void dialog_group_props         (GtkWindow * parent, Group *);

void dialog_log_viewer	        (void);

void dialog_rules               (void);

#endif
